Class: Aws::Schemas::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-schemas/client.rb

Overview

An API client for Schemas. To construct a client, you need to configure a ‘:region` and `:credentials`.

client = Aws::Schemas::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :plugins (Array<Seahorse::Client::Plugin>) — default: []]

    A list of plugins to apply to the client. Each plugin is either a class name or an instance of a plugin class.

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials used for authentication. This can be any class that includes and implements ‘Aws::CredentialProvider`, or instance of any one of the following classes:

    • ‘Aws::Credentials` - Used for configuring static, non-refreshing credentials.

    • ‘Aws::SharedCredentials` - Used for loading static credentials from a shared file, such as `~/.aws/config`.

    • ‘Aws::AssumeRoleCredentials` - Used when you need to assume a role.

    • ‘Aws::AssumeRoleWebIdentityCredentials` - Used when you need to assume a role after providing credentials via the web.

    • ‘Aws::SSOCredentials` - Used for loading credentials from AWS SSO using an access token generated from `aws login`.

    • ‘Aws::ProcessCredentials` - Used for loading credentials from a process that outputs to stdout.

    • ‘Aws::InstanceProfileCredentials` - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • ‘Aws::ECSCredentials` - Used for loading credentials from instances running in ECS.

    • ‘Aws::CognitoIdentityCredentials` - Used for loading credentials from the Cognito Identity service.

    When ‘:credentials` are not configured directly, the following locations will be searched for credentials:

    • Aws.config`

    • The ‘:access_key_id`, `:secret_access_key`, `:session_token`, and `:account_id` options.

    • ENV`, `ENV`, `ENV`, and `ENV`.

    • ‘~/.aws/credentials`

    • ‘~/.aws/config`

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of ‘Aws::InstanceProfileCredentials` or `Aws::ECSCredentials` to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting `ENV` to `true`.

  • :region (required, String)

    The AWS region to connect to. The configured ‘:region` is used to determine the service `:endpoint`. When not passed, a default `:region` is searched for in the following locations:

  • :access_key_id (String)
  • :account_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to ‘true`, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to `false`.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in ‘adaptive` retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a `RetryCapacityNotAvailableError` and will not retry instead of sleeping.

  • :auth_scheme_preference (Array<String>)

    A list of preferred authentication schemes to use when making a request. Supported values are: ‘sigv4`, `sigv4a`, `httpBearerAuth`, and `noAuth`. When set using `ENV` or in shared config as `auth_scheme_preference`, the value should be a comma-separated list.

  • :client_side_monitoring (Boolean) — default: false

    When ‘true`, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When ‘true`, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in ‘standard` and adaptive retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    When ‘true`, the SDK will not prepend the modeled host prefix to the endpoint.

  • :disable_request_compression (Boolean) — default: false

    When set to ‘true’ the request body will not be compressed for supported operations.

  • :endpoint (String, URI::HTTPS, URI::HTTP)

    Normally you should not configure the ‘:endpoint` option directly. This is normally constructed from the `:region` option. Configuring `:endpoint` is normally reserved for connecting to test or custom endpoints. The endpoint should be a URI formatted like:

    'http://example.com'
    'https://example.com'
    'http://example.com:123'
    
  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to ‘true`, endpoint discovery will be enabled for operations when available.

  • :ignore_configured_endpoint_urls (Boolean)

    Setting to true disables use of endpoint URLs provided via environment variables and the shared configuration file.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the ‘:logger` at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in ‘standard` and `adaptive` retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at ‘HOME/.aws/credentials`. When not specified, ’default’ is used.

  • :request_checksum_calculation (String) — default: "when_supported"

    Determines when a checksum will be calculated for request payloads. Values are:

    • ‘when_supported` - (default) When set, a checksum will be calculated for all request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` and/or a `requestAlgorithmMember` is modeled.

    • ‘when_required` - When set, a checksum will only be calculated for request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` or where a `requestAlgorithmMember` is modeled and supplied.

  • :request_min_compression_size_bytes (Integer) — default: 10240

    The minimum size in bytes that triggers compression for request bodies. The value must be non-negative integer value between 0 and 10485780 bytes inclusive.

  • :response_checksum_validation (String) — default: "when_supported"

    Determines when checksum validation will be performed on response payloads. Values are:

    • ‘when_supported` - (default) When set, checksum validation is performed on all response payloads of operations modeled with the `httpChecksum` trait where `responseAlgorithms` is modeled, except when no modeled checksum algorithms are supported.

    • ‘when_required` - When set, checksum validation is not performed on response payloads of operations unless the checksum algorithm is supported and the `requestValidationModeMember` member is set to `ENABLED`.

  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the ‘legacy` retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the ‘legacy` retry mode.

    @see www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the ‘legacy` retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • ‘legacy` - The pre-existing retry behavior. This is default value if no retry mode is provided.

    • ‘standard` - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • ‘adaptive` - An experimental retry mode that includes all the functionality of `standard` mode along with automatic client side throttling. This is a provisional mode that may change behavior in the future.

  • :sdk_ua_app_id (String)

    A unique and opaque application ID that is appended to the User-Agent header as app/sdk_ua_app_id. It should have a maximum length of 50. This variable is sourced from environment variable AWS_SDK_UA_APP_ID or the shared config profile attribute sdk_ua_app_id.

  • :secret_access_key (String)
  • :session_token (String)
  • :sigv4a_signing_region_set (Array)

    A list of regions that should be signed with SigV4a signing. When not passed, a default ‘:sigv4a_signing_region_set` is searched for in the following locations:

  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :telemetry_provider (Aws::Telemetry::TelemetryProviderBase) — default: Aws::Telemetry::NoOpTelemetryProvider

    Allows you to provide a telemetry provider, which is used to emit telemetry data. By default, uses ‘NoOpTelemetryProvider` which will not record or emit any telemetry data. The SDK supports the following telemetry providers:

    • OpenTelemetry (OTel) - To use the OTel provider, install and require the

    ‘opentelemetry-sdk` gem and then, pass in an instance of a `Aws::Telemetry::OTelProvider` for telemetry provider.

  • :token_provider (Aws::TokenProvider)

    Your Bearer token used for authentication. This can be any class that includes and implements ‘Aws::TokenProvider`, or instance of any one of the following classes:

    • ‘Aws::StaticTokenProvider` - Used for configuring static, non-refreshing tokens.

    • ‘Aws::SSOTokenProvider` - Used for loading tokens from AWS SSO using an access token generated from `aws login`.

    When ‘:token_provider` is not configured directly, the `Aws::TokenProviderChain` will be used to search for tokens configured for your profile in shared configuration files.

  • :use_dualstack_endpoint (Boolean)

    When set to ‘true`, dualstack enabled endpoints (with `.aws` TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to ‘true`, fips compatible endpoints will be used if available. When a `fips` region is used, the region is normalized and this config is set to `true`.

  • :validate_params (Boolean) — default: true

    When ‘true`, request parameters are validated before sending the request.

  • :endpoint_provider (Aws::Schemas::EndpointProvider)

    The endpoint provider used to resolve endpoints. Any object that responds to ‘#resolve_endpoint(parameters)` where `parameters` is a Struct similar to `Aws::Schemas::EndpointParameters`.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has “Expect” header set to “100-continue”. Defaults to ‘nil` which disables this behaviour. This value can safely be set per request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_open_timeout (Float) — default: 15

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like ‘proxy.com:123’.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_wire_trace (Boolean) — default: false

    When ‘true`, HTTP debug output will be sent to the `:logger`.

  • :on_chunk_received (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the response body is received. It provides three arguments: the chunk, the number of bytes received, and the total number of bytes in the response (or nil if the server did not send a ‘content-length`).

  • :on_chunk_sent (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the request body is sent. It provides three arguments: the chunk, the number of bytes read from the body, and the total number of bytes in the body.

  • :raise_response_errors (Boolean) — default: true

    When ‘true`, response errors are raised.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_store (String)

    Sets the X509::Store to verify peer certificate.

  • :ssl_cert (OpenSSL::X509::Certificate)

    Sets a client certificate when creating http connections.

  • :ssl_key (OpenSSL::PKey)

    Sets a client key when creating http connections.

  • :ssl_timeout (Float)

    Sets the SSL timeout in seconds

  • :ssl_verify_peer (Boolean) — default: true

    When ‘true`, SSL peer certificates are verified when establishing a connection.



473
474
475
# File 'lib/aws-sdk-schemas/client.rb', line 473

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1797
1798
1799
# File 'lib/aws-sdk-schemas/client.rb', line 1797

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1800
1801
1802
# File 'lib/aws-sdk-schemas/client.rb', line 1800

def errors_module
  Errors
end

Instance Method Details

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-schemas/client.rb', line 1657

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  tracer = config.telemetry_provider.tracer_provider.tracer(
    Aws::Telemetry.module_to_tracer_name('Aws::Schemas')
  )
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config,
    tracer: tracer
  )
  context[:gem_name] = 'aws-sdk-schemas'
  context[:gem_version] = '1.64.0'
  Seahorse::Client::Request.new(handlers, context)
end

#create_discoverer(params = {}) ⇒ Types::CreateDiscovererResponse

Creates a discoverer.

Examples:

Request syntax with placeholder values


resp = client.create_discoverer({
  description: "__stringMin0Max256",
  source_arn: "__stringMin20Max1600", # required
  cross_account: false,
  tags: {
    "__string" => "__string",
  },
})

Response structure


resp.description #=> String
resp.discoverer_arn #=> String
resp.discoverer_id #=> String
resp.source_arn #=> String
resp.state #=> String, one of "STARTED", "STOPPED"
resp. #=> Boolean
resp.tags #=> Hash
resp.tags["__string"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :description (String)
  • :source_arn (required, String)
  • :cross_account (Boolean)
  • :tags (Hash<String,String>)

    Key-value pairs associated with a resource.

Returns:

See Also:



526
527
528
529
# File 'lib/aws-sdk-schemas/client.rb', line 526

def create_discoverer(params = {}, options = {})
  req = build_request(:create_discoverer, params)
  req.send_request(options)
end

#create_registry(params = {}) ⇒ Types::CreateRegistryResponse

Creates a registry.

Examples:

Request syntax with placeholder values


resp = client.create_registry({
  description: "__stringMin0Max256",
  registry_name: "__string", # required
  tags: {
    "__string" => "__string",
  },
})

Response structure


resp.description #=> String
resp.registry_arn #=> String
resp.registry_name #=> String
resp.tags #=> Hash
resp.tags["__string"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :description (String)
  • :registry_name (required, String)
  • :tags (Hash<String,String>)

    Key-value pairs associated with a resource.

Returns:

See Also:



569
570
571
572
# File 'lib/aws-sdk-schemas/client.rb', line 569

def create_registry(params = {}, options = {})
  req = build_request(:create_registry, params)
  req.send_request(options)
end

#create_schema(params = {}) ⇒ Types::CreateSchemaResponse

Creates a schema definition.

<note markdown=“1”>Inactive schemas will be deleted after two years.

</note>

Examples:

Request syntax with placeholder values


resp = client.create_schema({
  content: "__stringMin1Max100000", # required
  description: "__stringMin0Max256",
  registry_name: "__string", # required
  schema_name: "__string", # required
  tags: {
    "__string" => "__string",
  },
  type: "OpenApi3", # required, accepts OpenApi3
})

Response structure


resp.description #=> String
resp.last_modified #=> Time
resp.schema_arn #=> String
resp.schema_name #=> String
resp.schema_version #=> String
resp.tags #=> Hash
resp.tags["__string"] #=> String
resp.type #=> String
resp.version_created_date #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :content (required, String)
  • :description (String)
  • :registry_name (required, String)
  • :schema_name (required, String)
  • :tags (Hash<String,String>)

    Key-value pairs associated with a resource.

  • :type (required, String)

Returns:

See Also:



633
634
635
636
# File 'lib/aws-sdk-schemas/client.rb', line 633

def create_schema(params = {}, options = {})
  req = build_request(:create_schema, params)
  req.send_request(options)
end

#delete_discoverer(params = {}) ⇒ Struct

Deletes a discoverer.

Examples:

Request syntax with placeholder values


resp = client.delete_discoverer({
  discoverer_id: "__string", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :discoverer_id (required, String)

Returns:

  • (Struct)

    Returns an empty response.

See Also:



654
655
656
657
# File 'lib/aws-sdk-schemas/client.rb', line 654

def delete_discoverer(params = {}, options = {})
  req = build_request(:delete_discoverer, params)
  req.send_request(options)
end

#delete_registry(params = {}) ⇒ Struct

Deletes a Registry.

Examples:

Request syntax with placeholder values


resp = client.delete_registry({
  registry_name: "__string", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :registry_name (required, String)

Returns:

  • (Struct)

    Returns an empty response.

See Also:



675
676
677
678
# File 'lib/aws-sdk-schemas/client.rb', line 675

def delete_registry(params = {}, options = {})
  req = build_request(:delete_registry, params)
  req.send_request(options)
end

#delete_resource_policy(params = {}) ⇒ Struct

Delete the resource-based policy attached to the specified registry.

Examples:

Request syntax with placeholder values


resp = client.delete_resource_policy({
  registry_name: "__string",
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :registry_name (String)

Returns:

  • (Struct)

    Returns an empty response.

See Also:



696
697
698
699
# File 'lib/aws-sdk-schemas/client.rb', line 696

def delete_resource_policy(params = {}, options = {})
  req = build_request(:delete_resource_policy, params)
  req.send_request(options)
end

#delete_schema(params = {}) ⇒ Struct

Delete a schema definition.

Examples:

Request syntax with placeholder values


resp = client.delete_schema({
  registry_name: "__string", # required
  schema_name: "__string", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :registry_name (required, String)
  • :schema_name (required, String)

Returns:

  • (Struct)

    Returns an empty response.

See Also:



720
721
722
723
# File 'lib/aws-sdk-schemas/client.rb', line 720

def delete_schema(params = {}, options = {})
  req = build_request(:delete_schema, params)
  req.send_request(options)
end

#delete_schema_version(params = {}) ⇒ Struct

Delete the schema version definition

Examples:

Request syntax with placeholder values


resp = client.delete_schema_version({
  registry_name: "__string", # required
  schema_name: "__string", # required
  schema_version: "__string", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :registry_name (required, String)
  • :schema_name (required, String)
  • :schema_version (required, String)

Returns:

  • (Struct)

    Returns an empty response.

See Also:



747
748
749
750
# File 'lib/aws-sdk-schemas/client.rb', line 747

def delete_schema_version(params = {}, options = {})
  req = build_request(:delete_schema_version, params)
  req.send_request(options)
end

#describe_code_binding(params = {}) ⇒ Types::DescribeCodeBindingResponse

Describe the code binding URI.

The following waiters are defined for this operation (see #wait_until for detailed usage):

* code_binding_exists

Examples:

Request syntax with placeholder values


resp = client.describe_code_binding({
  language: "__string", # required
  registry_name: "__string", # required
  schema_name: "__string", # required
  schema_version: "__string",
})

Response structure


resp.creation_date #=> Time
resp.last_modified #=> Time
resp.schema_version #=> String
resp.status #=> String, one of "CREATE_IN_PROGRESS", "CREATE_COMPLETE", "CREATE_FAILED"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :language (required, String)
  • :registry_name (required, String)
  • :schema_name (required, String)
  • :schema_version (String)

Returns:

See Also:



794
795
796
797
# File 'lib/aws-sdk-schemas/client.rb', line 794

def describe_code_binding(params = {}, options = {})
  req = build_request(:describe_code_binding, params)
  req.send_request(options)
end

#describe_discoverer(params = {}) ⇒ Types::DescribeDiscovererResponse

Describes the discoverer.

Examples:

Request syntax with placeholder values


resp = client.describe_discoverer({
  discoverer_id: "__string", # required
})

Response structure


resp.description #=> String
resp.discoverer_arn #=> String
resp.discoverer_id #=> String
resp.source_arn #=> String
resp.state #=> String, one of "STARTED", "STOPPED"
resp. #=> Boolean
resp.tags #=> Hash
resp.tags["__string"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :discoverer_id (required, String)

Returns:

See Also:



834
835
836
837
# File 'lib/aws-sdk-schemas/client.rb', line 834

def describe_discoverer(params = {}, options = {})
  req = build_request(:describe_discoverer, params)
  req.send_request(options)
end

#describe_registry(params = {}) ⇒ Types::DescribeRegistryResponse

Describes the registry.

Examples:

Request syntax with placeholder values


resp = client.describe_registry({
  registry_name: "__string", # required
})

Response structure


resp.description #=> String
resp.registry_arn #=> String
resp.registry_name #=> String
resp.tags #=> Hash
resp.tags["__string"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :registry_name (required, String)

Returns:

See Also:



868
869
870
871
# File 'lib/aws-sdk-schemas/client.rb', line 868

def describe_registry(params = {}, options = {})
  req = build_request(:describe_registry, params)
  req.send_request(options)
end

#describe_schema(params = {}) ⇒ Types::DescribeSchemaResponse

Retrieve the schema definition.

Examples:

Request syntax with placeholder values


resp = client.describe_schema({
  registry_name: "__string", # required
  schema_name: "__string", # required
  schema_version: "__string",
})

Response structure


resp.content #=> String
resp.description #=> String
resp.last_modified #=> Time
resp.schema_arn #=> String
resp.schema_name #=> String
resp.schema_version #=> String
resp.tags #=> Hash
resp.tags["__string"] #=> String
resp.type #=> String
resp.version_created_date #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :registry_name (required, String)
  • :schema_name (required, String)
  • :schema_version (String)

Returns:

See Also:



918
919
920
921
# File 'lib/aws-sdk-schemas/client.rb', line 918

def describe_schema(params = {}, options = {})
  req = build_request(:describe_schema, params)
  req.send_request(options)
end

#export_schema(params = {}) ⇒ Types::ExportSchemaResponse

Exports a schema to a different specification.

Examples:

Request syntax with placeholder values


resp = client.export_schema({
  registry_name: "__string", # required
  schema_name: "__string", # required
  schema_version: "__string",
  type: "__string", # required
})

Response structure


resp.content #=> String
resp.schema_arn #=> String
resp.schema_name #=> String
resp.schema_version #=> String
resp.type #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :registry_name (required, String)
  • :schema_name (required, String)
  • :schema_version (String)
  • :type (required, String)

Returns:

See Also:



1648
1649
1650
1651
# File 'lib/aws-sdk-schemas/client.rb', line 1648

def export_schema(params = {}, options = {})
  req = build_request(:export_schema, params)
  req.send_request(options)
end

#get_code_binding_source(params = {}) ⇒ Types::GetCodeBindingSourceResponse

Get the code binding source URI.

Examples:

Request syntax with placeholder values


resp = client.get_code_binding_source({
  language: "__string", # required
  registry_name: "__string", # required
  schema_name: "__string", # required
  schema_version: "__string",
})

Response structure


resp.body #=> IO

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :language (required, String)
  • :registry_name (required, String)
  • :schema_name (required, String)
  • :schema_version (String)

Returns:

See Also:



954
955
956
957
# File 'lib/aws-sdk-schemas/client.rb', line 954

def get_code_binding_source(params = {}, options = {}, &block)
  req = build_request(:get_code_binding_source, params)
  req.send_request(options, &block)
end

#get_discovered_schema(params = {}) ⇒ Types::GetDiscoveredSchemaResponse

Get the discovered schema that was generated based on sampled events.

Examples:

Request syntax with placeholder values


resp = client.get_discovered_schema({
  events: ["GetDiscoveredSchemaVersionItemInput"], # required
  type: "OpenApi3", # required, accepts OpenApi3
})

Response structure


resp.content #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :events (required, Array<String>)
  • :type (required, String)

Returns:

See Also:



984
985
986
987
# File 'lib/aws-sdk-schemas/client.rb', line 984

def get_discovered_schema(params = {}, options = {})
  req = build_request(:get_discovered_schema, params)
  req.send_request(options)
end

#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse

Retrieves the resource-based policy attached to a given registry.

Examples:

Request syntax with placeholder values


resp = client.get_resource_policy({
  registry_name: "__string",
})

Response structure


resp.policy #=> String
resp.revision_id #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :registry_name (String)

Returns:

See Also:



1013
1014
1015
1016
# File 'lib/aws-sdk-schemas/client.rb', line 1013

def get_resource_policy(params = {}, options = {})
  req = build_request(:get_resource_policy, params)
  req.send_request(options)
end

#list_discoverers(params = {}) ⇒ Types::ListDiscoverersResponse

List the discoverers.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_discoverers({
  discoverer_id_prefix: "__string",
  limit: 1,
  next_token: "__string",
  source_arn_prefix: "__string",
})

Response structure


resp.discoverers #=> Array
resp.discoverers[0].discoverer_arn #=> String
resp.discoverers[0].discoverer_id #=> String
resp.discoverers[0].source_arn #=> String
resp.discoverers[0].state #=> String, one of "STARTED", "STOPPED"
resp.discoverers[0]. #=> Boolean
resp.discoverers[0].tags #=> Hash
resp.discoverers[0].tags["__string"] #=> String
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :discoverer_id_prefix (String)
  • :limit (Integer)
  • :next_token (String)
  • :source_arn_prefix (String)

Returns:

See Also:



1060
1061
1062
1063
# File 'lib/aws-sdk-schemas/client.rb', line 1060

def list_discoverers(params = {}, options = {})
  req = build_request(:list_discoverers, params)
  req.send_request(options)
end

#list_registries(params = {}) ⇒ Types::ListRegistriesResponse

List the registries.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_registries({
  limit: 1,
  next_token: "__string",
  registry_name_prefix: "__string",
  scope: "__string",
})

Response structure


resp.next_token #=> String
resp.registries #=> Array
resp.registries[0].registry_arn #=> String
resp.registries[0].registry_name #=> String
resp.registries[0].tags #=> Hash
resp.registries[0].tags["__string"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :limit (Integer)
  • :next_token (String)
  • :registry_name_prefix (String)
  • :scope (String)

Returns:

See Also:



1104
1105
1106
1107
# File 'lib/aws-sdk-schemas/client.rb', line 1104

def list_registries(params = {}, options = {})
  req = build_request(:list_registries, params)
  req.send_request(options)
end

#list_schema_versions(params = {}) ⇒ Types::ListSchemaVersionsResponse

Provides a list of the schema versions and related information.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_schema_versions({
  limit: 1,
  next_token: "__string",
  registry_name: "__string", # required
  schema_name: "__string", # required
})

Response structure


resp.next_token #=> String
resp.schema_versions #=> Array
resp.schema_versions[0].schema_arn #=> String
resp.schema_versions[0].schema_name #=> String
resp.schema_versions[0].schema_version #=> String
resp.schema_versions[0].type #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :limit (Integer)
  • :next_token (String)
  • :registry_name (required, String)
  • :schema_name (required, String)

Returns:

See Also:



1148
1149
1150
1151
# File 'lib/aws-sdk-schemas/client.rb', line 1148

def list_schema_versions(params = {}, options = {})
  req = build_request(:list_schema_versions, params)
  req.send_request(options)
end

#list_schemas(params = {}) ⇒ Types::ListSchemasResponse

List the schemas.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_schemas({
  limit: 1,
  next_token: "__string",
  registry_name: "__string", # required
  schema_name_prefix: "__string",
})

Response structure


resp.next_token #=> String
resp.schemas #=> Array
resp.schemas[0].last_modified #=> Time
resp.schemas[0].schema_arn #=> String
resp.schemas[0].schema_name #=> String
resp.schemas[0].tags #=> Hash
resp.schemas[0].tags["__string"] #=> String
resp.schemas[0].version_count #=> Integer

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :limit (Integer)
  • :next_token (String)
  • :registry_name (required, String)
  • :schema_name_prefix (String)

Returns:

See Also:



1194
1195
1196
1197
# File 'lib/aws-sdk-schemas/client.rb', line 1194

def list_schemas(params = {}, options = {})
  req = build_request(:list_schemas, params)
  req.send_request(options)
end

#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse

Get tags for resource.

Examples:

Request syntax with placeholder values


resp = client.list_tags_for_resource({
  resource_arn: "__string", # required
})

Response structure


resp.tags #=> Hash
resp.tags["__string"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

Returns:

See Also:



1222
1223
1224
1225
# File 'lib/aws-sdk-schemas/client.rb', line 1222

def list_tags_for_resource(params = {}, options = {})
  req = build_request(:list_tags_for_resource, params)
  req.send_request(options)
end

#put_code_binding(params = {}) ⇒ Types::PutCodeBindingResponse

Put code binding URI

Examples:

Request syntax with placeholder values


resp = client.put_code_binding({
  language: "__string", # required
  registry_name: "__string", # required
  schema_name: "__string", # required
  schema_version: "__string",
})

Response structure


resp.creation_date #=> Time
resp.last_modified #=> Time
resp.schema_version #=> String
resp.status #=> String, one of "CREATE_IN_PROGRESS", "CREATE_COMPLETE", "CREATE_FAILED"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :language (required, String)
  • :registry_name (required, String)
  • :schema_name (required, String)
  • :schema_version (String)

Returns:

See Also:



1264
1265
1266
1267
# File 'lib/aws-sdk-schemas/client.rb', line 1264

def put_code_binding(params = {}, options = {})
  req = build_request(:put_code_binding, params)
  req.send_request(options)
end

#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse

The name of the policy.

Examples:

Request syntax with placeholder values


resp = client.put_resource_policy({
  policy: "__string", # required
  registry_name: "__string",
  revision_id: "__string",
})

Response structure


resp.policy #=> String
resp.revision_id #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :policy (required, String)

    **SDK automatically handles json encoding and base64 encoding for you when the required value (Hash, Array, etc.) is provided according to the description.**

  • :registry_name (String)
  • :revision_id (String)

Returns:

See Also:



1302
1303
1304
1305
# File 'lib/aws-sdk-schemas/client.rb', line 1302

def put_resource_policy(params = {}, options = {})
  req = build_request(:put_resource_policy, params)
  req.send_request(options)
end

#search_schemas(params = {}) ⇒ Types::SearchSchemasResponse

Search the schemas

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.search_schemas({
  keywords: "__string", # required
  limit: 1,
  next_token: "__string",
  registry_name: "__string", # required
})

Response structure


resp.next_token #=> String
resp.schemas #=> Array
resp.schemas[0].registry_name #=> String
resp.schemas[0].schema_arn #=> String
resp.schemas[0].schema_name #=> String
resp.schemas[0].schema_versions #=> Array
resp.schemas[0].schema_versions[0].created_date #=> Time
resp.schemas[0].schema_versions[0].schema_version #=> String
resp.schemas[0].schema_versions[0].type #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :keywords (required, String)
  • :limit (Integer)
  • :next_token (String)
  • :registry_name (required, String)

Returns:

See Also:



1349
1350
1351
1352
# File 'lib/aws-sdk-schemas/client.rb', line 1349

def search_schemas(params = {}, options = {})
  req = build_request(:search_schemas, params)
  req.send_request(options)
end

#start_discoverer(params = {}) ⇒ Types::StartDiscovererResponse

Starts the discoverer

Examples:

Request syntax with placeholder values


resp = client.start_discoverer({
  discoverer_id: "__string", # required
})

Response structure


resp.discoverer_id #=> String
resp.state #=> String, one of "STARTED", "STOPPED"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :discoverer_id (required, String)

Returns:

See Also:



1378
1379
1380
1381
# File 'lib/aws-sdk-schemas/client.rb', line 1378

def start_discoverer(params = {}, options = {})
  req = build_request(:start_discoverer, params)
  req.send_request(options)
end

#stop_discoverer(params = {}) ⇒ Types::StopDiscovererResponse

Stops the discoverer

Examples:

Request syntax with placeholder values


resp = client.stop_discoverer({
  discoverer_id: "__string", # required
})

Response structure


resp.discoverer_id #=> String
resp.state #=> String, one of "STARTED", "STOPPED"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :discoverer_id (required, String)

Returns:

See Also:



1407
1408
1409
1410
# File 'lib/aws-sdk-schemas/client.rb', line 1407

def stop_discoverer(params = {}, options = {})
  req = build_request(:stop_discoverer, params)
  req.send_request(options)
end

#tag_resource(params = {}) ⇒ Struct

Add tags to a resource.

Examples:

Request syntax with placeholder values


resp = client.tag_resource({
  resource_arn: "__string", # required
  tags: { # required
    "__string" => "__string",
  },
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)
  • :tags (required, Hash<String,String>)

    Key-value pairs associated with a resource.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1434
1435
1436
1437
# File 'lib/aws-sdk-schemas/client.rb', line 1434

def tag_resource(params = {}, options = {})
  req = build_request(:tag_resource, params)
  req.send_request(options)
end

#untag_resource(params = {}) ⇒ Struct

Removes tags from a resource.

Examples:

Request syntax with placeholder values


resp = client.untag_resource({
  resource_arn: "__string", # required
  tag_keys: ["__string"], # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)
  • :tag_keys (required, Array<String>)

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1458
1459
1460
1461
# File 'lib/aws-sdk-schemas/client.rb', line 1458

def untag_resource(params = {}, options = {})
  req = build_request(:untag_resource, params)
  req.send_request(options)
end

#update_discoverer(params = {}) ⇒ Types::UpdateDiscovererResponse

Updates the discoverer

Examples:

Request syntax with placeholder values


resp = client.update_discoverer({
  description: "__stringMin0Max256",
  discoverer_id: "__string", # required
  cross_account: false,
})

Response structure


resp.description #=> String
resp.discoverer_arn #=> String
resp.discoverer_id #=> String
resp.source_arn #=> String
resp.state #=> String, one of "STARTED", "STOPPED"
resp. #=> Boolean
resp.tags #=> Hash
resp.tags["__string"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :description (String)
  • :discoverer_id (required, String)
  • :cross_account (Boolean)

Returns:

See Also:



1504
1505
1506
1507
# File 'lib/aws-sdk-schemas/client.rb', line 1504

def update_discoverer(params = {}, options = {})
  req = build_request(:update_discoverer, params)
  req.send_request(options)
end

#update_registry(params = {}) ⇒ Types::UpdateRegistryResponse

Updates a registry.

Examples:

Request syntax with placeholder values


resp = client.update_registry({
  description: "__stringMin0Max256",
  registry_name: "__string", # required
})

Response structure


resp.description #=> String
resp.registry_arn #=> String
resp.registry_name #=> String
resp.tags #=> Hash
resp.tags["__string"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :description (String)
  • :registry_name (required, String)

Returns:

See Also:



1541
1542
1543
1544
# File 'lib/aws-sdk-schemas/client.rb', line 1541

def update_registry(params = {}, options = {})
  req = build_request(:update_registry, params)
  req.send_request(options)
end

#update_schema(params = {}) ⇒ Types::UpdateSchemaResponse

Updates the schema definition

<note markdown=“1”>Inactive schemas will be deleted after two years.

</note>

Examples:

Request syntax with placeholder values


resp = client.update_schema({
  client_token_id: "__stringMin0Max36",
  content: "__stringMin1Max100000",
  description: "__stringMin0Max256",
  registry_name: "__string", # required
  schema_name: "__string", # required
  type: "OpenApi3", # accepts OpenApi3
})

Response structure


resp.description #=> String
resp.last_modified #=> Time
resp.schema_arn #=> String
resp.schema_name #=> String
resp.schema_version #=> String
resp.tags #=> Hash
resp.tags["__string"] #=> String
resp.type #=> String
resp.version_created_date #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :client_token_id (String)

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

  • :content (String)
  • :description (String)
  • :registry_name (required, String)
  • :schema_name (required, String)
  • :type (String)

Returns:

See Also:



1604
1605
1606
1607
# File 'lib/aws-sdk-schemas/client.rb', line 1604

def update_schema(params = {}, options = {})
  req = build_request(:update_schema, params)
  req.send_request(options)
end

#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean

Polls an API operation until a resource enters a desired state.

## Basic Usage

A waiter will call an API operation until:

  • It is successful

  • It enters a terminal state

  • It makes the maximum number of attempts

In between attempts, the waiter will sleep.

# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)

## Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.

# poll for ~25 seconds
client.wait_until(waiter_name, params, {
  max_attempts: 5,
  delay: 5,
})

## Callbacks

You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.

started_at = Time.now
client.wait_until(waiter_name, params, {

  # disable max attempts
  max_attempts: nil,

  # poll for 1 hour, instead of a number of attempts
  before_wait: -> (attempts, response) do
    throw :failure if Time.now - started_at > 3600
  end
})

## Handling Errors

When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.

begin
  client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

## Valid Waiters

The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.

| waiter_name | params | :delay | :max_attempts | | ——————- | —————————— | ——– | ————- | | code_binding_exists | #describe_code_binding | 2 | 30 |

Parameters:

  • waiter_name (Symbol)
  • params (Hash) (defaults to: {})

    ({})

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :max_attempts (Integer)
  • :delay (Integer)
  • :before_attempt (Proc)
  • :before_wait (Proc)

Yields:

  • (w.waiter)

Returns:

  • (Boolean)

    Returns ‘true` if the waiter was successful.

Raises:

  • (Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

  • (Errors::TooManyAttemptsError)

    Raised when the configured maximum number of attempts have been made, and the waiter is not yet successful.

  • (Errors::UnexpectedError)

    Raised when an error is encounted while polling for a resource that is not expected.

  • (Errors::NoSuchWaiterError)

    Raised when you request to wait for an unknown state.



1763
1764
1765
1766
1767
# File 'lib/aws-sdk-schemas/client.rb', line 1763

def wait_until(waiter_name, params = {}, options = {})
  w = waiter(waiter_name, options)
  yield(w.waiter) if block_given? # deprecated
  w.wait(params)
end

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


1771
1772
1773
# File 'lib/aws-sdk-schemas/client.rb', line 1771

def waiter_names
  waiters.keys
end